@@ -78,6 +78,38 @@ class LogPlayerTakeDamage(Event):
         self.damage_reason = self._data.get('damageReason')
         self.damage = self._data.get('damage')
         self.damage_causer_name = self._data.get('damageCauserName')
+        self.is_through_penetrable_wall = self._data.get(
+            'isThroughPenetrableWall')
+
+
+class LogPlayerUseFlareGun(Event):
+
+    def from_dict(self):
+        super().from_dict()
+        self.attack_id = self._data.get('attackId')
+        self.fire_weapon_stack_count = self._data.get('fireWeaponStackCount')
+        self.attacker = objects.Character(self._data.get('attacker', {}))
+        self.attack_type = self._data.get('attackType')
+        self.weapon = objects.Item(self._data.get('weapon', {}))
+
+
+class LogPlayerUseThrowable(Event):
+
+    def from_dict(self):
+        super().from_dict()
+        self.attack_id = self._data.get('attackId')
+        self.fire_weapon_stack_count = self._data.get('fireWeaponStackCount')
+        self.attacker = objects.Character(self._data.get('attacker', {}))
+        self.attack_type = self._data.get('attackType')
+        self.weapon = objects.Item(self._data.get('weapon', {}))
+
+
+class LogPlayerDestroyBreachableWall(Event):
+
+    def from_dict(self):
+        super().from_dict()
+        self.attacker = objects.Character(self._data.get('character', {}))
+        self.weapon = objects.Item(self._data.get('weapon', {}))
 
 
 class LogPlayerKill(Event):
@@ -100,6 +132,8 @@ class LogPlayerKill(Event):
         self.distance = self._data.get('distance')
         self.victim_game_result = objects.GameResult(
             self._data.get('victimGameResult', {}))
+        self.is_through_penetrable_wall = self._data.get(
+            'isThroughPenetrableWall')
 
 
 class LogParachuteLanding(Event):
@@ -175,6 +209,8 @@ class LogHeal(Event):
 
     def from_dict(self):
         super().from_dict()
+        self.character = objects.Character(self._data.get('character', {}))
+        self.item = objects.Item(self._data.get('item', {}))
         self.heal_amount = self._data.get('healAmount')
 
 
@@ -276,6 +312,16 @@ class LogMatchDefinition(Event):
         self.season_state = self._data.get('SeasonState')
 
 
+class LogBlackZoneEnded(Event):
+
+    def from_dict(self):
+        super().from_dict()
+        self.survivors = [
+            objects.Character(data)
+            for data in self._data.get('characters', [])
+        ]
+
+
 class LogMatchEvent(Event):
 
     def from_dict(self):
@@ -398,14 +444,3 @@ class LogPhaseChange(Event):
     def from_dict(self):
         super().from_dict()
         self.phase = self._data.get('phase')
-
-
-class LogPlayerUseThrowable(Event):
-
-    def from_dict(self):
-        super().from_dict()
-        self.attackId = self._data.get('attackId')
-        self.fire_weapon_stack_count = self._data.get('fireWeaponStackCount')
-        self.attacker = objects.Character(self._data.get('attacker', {}))
-        self.attack_type = self._data.get('attackType')
-        self.weapon = objects.Item(self._data.get('weapon', {}))
